#[non_exhaustive]
pub enum Event<'a> { Buttons { buttons: Vec<u8>, }, Ring { ring: ZwpTabletPadRingV2, }, Strip { strip: ZwpTabletPadStripV2, }, Modes { modes: u32, }, Done, ModeSwitch { time: u32, serial: u32, mode: u32, }, Dial { dial: ZwpTabletPadDialV2, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Buttons

buttons announced

Sent on zwp_tablet_pad_group_v2 initialization to announce the available buttons in the group. Button indices start at 0, a button may only be in one group at a time.

This event is first sent in the initial burst of events before the zwp_tablet_pad_group_v2.done event.

Some buttons are reserved by the compositor. These buttons may not be assigned to any zwp_tablet_pad_group_v2. Compositors may broadcast this event in the case of changes to the mapping of these reserved buttons. If the compositor happens to reserve all buttons in a group, this event will be sent with an empty array.

Fields

buttons: Vec<u8>

buttons in this group



Ring

ring announced

Sent on zwp_tablet_pad_group_v2 initialization to announce available rings. One event is sent for each ring available on this pad group.

This event is sent in the initial burst of events before the zwp_tablet_pad_group_v2.done event.



Strip

strip announced

Sent on zwp_tablet_pad_v2 initialization to announce available strips. One event is sent for each strip available on this pad group.

This event is sent in the initial burst of events before the zwp_tablet_pad_group_v2.done event.



Modes

mode-switch ability announced

Sent on zwp_tablet_pad_group_v2 initialization to announce that the pad group may switch between modes. A client may use a mode to store a specific configuration for buttons, rings and strips and use the zwp_tablet_pad_group_v2.mode_switch event to toggle between these configurations. Mode indices start at 0.

Switching modes is compositor-dependent. See the zwp_tablet_pad_group_v2.mode_switch event for more details.

This event is sent in the initial burst of events before the zwp_tablet_pad_group_v2.done event. This event is only sent when more than more than one mode is available.

Fields

modes: u32

the number of modes



Done

tablet group description events sequence complete

This event is sent immediately to signal the end of the initial burst of descriptive events. A client may consider the static description of the tablet to be complete and finalize initialization of the tablet group.



ModeSwitch

mode switch event

Notification that the mode was switched.

A mode applies to all buttons, rings, strips and dials in a group simultaneously, but a client is not required to assign different actions for each mode. For example, a client may have mode-specific button mappings but map the ring to vertical scrolling in all modes. Mode indices start at 0.

Switching modes is compositor-dependent. The compositor may provide visual cues to the user about the mode, e.g. by toggling LEDs on the tablet device. Mode-switching may be software-controlled or controlled by one or more physical buttons. For example, on a Wacom Intuos Pro, the button inside the ring may be assigned to switch between modes.

The compositor will also send this event after zwp_tablet_pad_v2.enter on each group in order to notify of the current mode. Groups that only feature one mode will use mode=0 when emitting this event.

If a button action in the new mode differs from the action in the previous mode, the client should immediately issue a zwp_tablet_pad_v2.set_feedback request for each changed button.

If a ring, strip or dial action in the new mode differs from the action in the previous mode, the client should immediately issue a zwp_tablet_ring_v2.set_feedback, zwp_tablet_strip_v2.set_feedback or zwp_tablet_dial_v2.set_feedback request for each changed ring, strip or dial.

Fields

time: u32

the time of the event with millisecond granularity

serial: u32
mode: u32

the new mode of the pad



Dial

dial announced

Sent on zwp_tablet_pad_v2 initialization to announce available dials. One event is sent for each dial available on this pad group.

This event is sent in the initial burst of events before the zwp_tablet_pad_group_v2.done event.

Only available since version 2 of the interface

Implementations



impl<'a> Event<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message